@@ -99,13 +99,16 @@ def boost_python_dlopen_flags():
     """A context manager that temporarily sets the dlopen flags for loading multiple
     boost.python modules and then returns them to previous values.
     """
+    flags = None
     try:
         import DLFCN
         flags = DLFCN.RTLD_NOW | DLFCN.RTLD_GLOBAL
-        with preserve_dlopenflags(flags):
-            yield
     except:
         import warnings
         warnings.warn('Do not know which dlopen flags to set.')
+    if None != flags:
+        with preserve_dlopenflags(flags):
+            yield
+    else:
         yield
 
